@@ -38,7 +38,7 @@ from warnings import warn_explicit
 from praw import decorators, errors, helpers
 from praw.settings import CONFIG
 
-__version__ = '2.0.5'
+__version__ = '2.0.6'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -120,6 +120,7 @@ class Config(object):  # pylint: disable-msg=R0903
                  'unfriend':            'api/unfriend/',
                  'unhide':              'api/unhide/',
                  'unmarknsfw':          'api/unmarknsfw/',
+                 'unmoderated':         'r/%s/about/unmoderated/',
                  'unread':              'message/unread/',
                  'unread_message':      'api/unread_message/',
                  'unsave':              'api/unsave/',
@@ -1255,6 +1256,12 @@ class ModOnlyMixin(AuthenticatedReddit):
         return self.request_json(self.config['stylesheet'] %
                                  six.text_type(subreddit))['data']
 
+    @decorators.restrict_access(scope=None, mod=True)
+    def get_unmoderated(self, subreddit='mod', limit=0):
+        """Return a get_content generator of unmoderated items."""
+        return self.get_content(self.config['unmoderated'] %
+                                six.text_type(subreddit), limit=limit)
+
 
 class MySubredditsMixin(AuthenticatedReddit):
 
